@@ -147,6 +147,7 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
           edges {
             node {
               name
+              path
               id
               webUrl
               repository {
@@ -155,8 +156,12 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
                     path
                     rawBlob
                     size
+                    oid
                   }
                 }
+                lastCommit {
+                  sha
+                }
               }
             }
           }
@@ -171,6 +176,7 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
       query GetFilesByRepo($fullPath: ID!, $file_paths: [String!]!) {
         project(fullPath: $fullPath) {
           name
+          path
           id
           webUrl
           repository {
@@ -179,8 +185,12 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
                 path
                 rawBlob
                 size
+                oid
               }
             }
+            lastCommit {
+              sha
+            }
           }
         }
       }
@@ -213,6 +223,9 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
                 }
               }
             }
+            lastCommit {
+              sha
+            }
           }
         }
       }
@@ -274,9 +287,13 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
           repo_id: id
           repo_name: name
           repo_path: path
+          repo_fullpath: fullPath
           ... on Project {
             repository {
               rootRef
+              lastCommit {
+                sha
+              }
             }
           }
           stars: starCount
