@@ -68,8 +68,8 @@ GitHost <- R6::R6Class(
                          with_code = NULL,
                          in_files = NULL,
                          with_file = NULL,
+                         language = NULL,
                          output = "table",
-                         force_orgs = FALSE,
                          verbose = TRUE,
                          progress = TRUE) {
       if (is.null(with_code) && is.null(with_file)) {
@@ -82,8 +82,8 @@ GitHost <- R6::R6Class(
         repos_table <- private$get_repos_with_code(
           code = with_code,
           in_files = in_files,
+          language = language,
           output = output,
-          force_orgs = force_orgs,
           verbose = verbose,
           progress = progress
         )
@@ -91,8 +91,8 @@ GitHost <- R6::R6Class(
         repos_table <- private$get_repos_with_code(
           code = with_file,
           in_path = TRUE,
+          language = language,
           output = output,
-          force_orgs = force_orgs,
           verbose = verbose,
           progress = progress
         )
@@ -100,6 +100,12 @@ GitHost <- R6::R6Class(
       if (output == "table") {
         repos_table <- private$add_repo_api_url(repos_table) %>%
           private$add_githost_info()
+        if (!is.null(language)) {
+          repos_table <- private$filter_repos_table_by_language(
+            repos_table = repos_table,
+            language_filter = language
+          )
+        }
         if (add_contributors) {
           repos_table <- private$get_repos_contributors(
             repos_table = repos_table,
@@ -526,7 +532,8 @@ GitHost <- R6::R6Class(
         cli::cli_alert(cli::col_grey("Checking owners..."))
       }
       orgs <- private$engines$graphql$set_owner_type(
-        owners = utils::URLdecode(orgs)
+        owners = utils::URLdecode(orgs),
+        verbose = verbose
       ) |>
         purrr::map(function(org) {
           if (attr(org, "type") == "not found") {
@@ -565,7 +572,8 @@ GitHost <- R6::R6Class(
       check <- TRUE
       endpoint_response <- private$engines$rest$perform_request(
         endpoint = endpoint,
-        token = private$token
+        token = private$token,
+        verbose = verbose
       )
       if (endpoint_response$status_code == 404) {
         if (.error) {
@@ -695,7 +703,8 @@ GitHost <- R6::R6Class(
       }
       if ("repo" %in% private$searching_scope) {
         orgs_names_from_repos <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         ) |>
           purrr::keep(function(org) {
             type <- attr(org, "type") %||% "organization"
@@ -707,7 +716,8 @@ GitHost <- R6::R6Class(
         type <- attr(org, "type") %||% "organization"
         org <- utils::URLdecode(org)
         graphql_engine$get_org(
-          org = org
+          org = org,
+          verbose = verbose
         )
       }) |>
         graphql_engine$prepare_orgs_table()
@@ -788,7 +798,8 @@ GitHost <- R6::R6Class(
       if ("repo" %in% private$searching_scope) {
         graphql_engine <- private$engines$graphql
         orgs <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         )
         purrr::map(orgs, function(org) {
           owner_type <- attr(org, "type") %||% "organization"
@@ -844,25 +855,27 @@ GitHost <- R6::R6Class(
     get_repos_with_code = function(code,
                                    in_files = NULL,
                                    in_path = FALSE,
+                                   language = NULL,
                                    output = "table_full",
-                                   force_orgs = FALSE,
                                    verbose = TRUE,
                                    progress = TRUE) {
-      if (private$scan_all && !force_orgs) {
+      if (private$scan_all) {
         repos_table <- private$get_repos_with_code_from_host(
           code = code,
           in_files = in_files,
           in_path = in_path,
+          language = language,
           output = output,
           verbose = verbose,
           progress = progress
         )
       }
-      if (!private$scan_all || force_orgs) {
+      if (!private$scan_all) {
         repos_from_org <- private$get_repos_with_code_from_orgs(
           code = code,
           in_files = in_files,
           in_path = in_path,
+          language = language,
           output = output,
           verbose = verbose,
           progress = progress
@@ -871,6 +884,7 @@ GitHost <- R6::R6Class(
           code = code,
           in_files = in_files,
           in_path = in_path,
+          language = language,
           output = output,
           verbose = verbose,
           progress = progress
@@ -933,7 +947,8 @@ GitHost <- R6::R6Class(
         rest_engine <- private$engines$rest
         graphql_engine <- private$engines$graphql
         orgs <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         )
         repos_vector <- purrr::map(orgs, function(org) {
           if (!private$scan_all && verbose) {
@@ -958,6 +973,7 @@ GitHost <- R6::R6Class(
     get_repos_with_code_from_host = function(code,
                                              in_files = NULL,
                                              in_path = FALSE,
+                                             language = NULL,
                                              output = "table_full",
                                              verbose = TRUE,
                                              progress = TRUE) {
@@ -973,6 +989,7 @@ GitHost <- R6::R6Class(
         search_response <- rest_engine$search_for_code(
           code = code,
           in_path = in_path,
+          language = language,
           verbose = verbose
         )
       } else {
@@ -981,6 +998,7 @@ GitHost <- R6::R6Class(
             code = code,
             filename = filename,
             in_path = in_path,
+            language = language,
             verbose = verbose
           )
         }) |>
@@ -997,6 +1015,7 @@ GitHost <- R6::R6Class(
     get_repos_with_code_from_orgs = function(code,
                                              in_files = NULL,
                                              in_path = FALSE,
+                                             language = NULL,
                                              output = "table",
                                              verbose = TRUE,
                                              progress = TRUE) {
@@ -1017,6 +1036,7 @@ GitHost <- R6::R6Class(
               org = org,
               code = code,
               in_path = in_path,
+              language = language,
               verbose = verbose
             )
           } else {
@@ -1026,6 +1046,7 @@ GitHost <- R6::R6Class(
                 code = code,
                 filename = filename,
                 in_path = in_path,
+                language = language,
                 verbose = verbose
               )
             }) %>%
@@ -1053,9 +1074,10 @@ GitHost <- R6::R6Class(
 
     get_repos_with_code_from_repos = function(code,
                                               in_files = NULL,
-                                              in_path  = FALSE,
-                                              output   = "table_full",
-                                              verbose  = TRUE,
+                                              in_path = FALSE,
+                                              language = NULL,
+                                              output = "table_full",
+                                              verbose = TRUE,
                                               progress = TRUE) {
       orgs <- names(private$orgs_repos)
       if ("repo" %in% private$searching_scope) {
@@ -1074,6 +1096,7 @@ GitHost <- R6::R6Class(
             repos = private$repos_fullnames,
             code = code,
             in_path = in_path,
+            language = language,
             verbose = verbose
           )
         } else {
@@ -1083,6 +1106,7 @@ GitHost <- R6::R6Class(
               code = code,
               filename = filename,
               in_path = in_path,
+              language = language,
               verbose = verbose
             )
           }) %>%
@@ -1100,32 +1124,15 @@ GitHost <- R6::R6Class(
     parse_search_response = function(search_response, org = NULL, output, verbose = TRUE) {
       if (length(search_response) > 0) {
         repos_ids <- private$get_repos_ids(search_response)
-        graphql_engine <- private$engines$graphql
-        if (!is.null(org)) {
-          owner_type <- attr(org, "type") %||% "organization"
-          repos_from_org <- graphql_engine$get_repos_from_org(
-            org = org,
-            owner_type = owner_type,
-            verbose = verbose
-          )
-          repos_response <- repos_from_org |>
-            purrr::keep(function(repo) {
-              if (is.null(repo$node)) {
-                repo_node <- repo
-              } else {
-                repo_node <- repo$node
-              }
-              any(purrr::map_lgl(repos_ids, ~ grepl(., repo_node$repo_id)))
-            })
-        } else {
-          repos_response <- graphql_engine$get_repos(
-            repos_ids = repos_ids,
-            verbose = verbose
-          )
-        }
+        api_engine <- private$engines$graphql
+        if (verbose) cli::cli_alert("Parsing search response with GraphQL...")
+        repos_response <- api_engine$get_repos(
+          repos_ids = repos_ids,
+          verbose = verbose
+        )
         if (output != "raw") {
           repos_output <- repos_response |>
-            graphql_engine$prepare_repos_table(
+            api_engine$prepare_repos_table(
               org = org
             )
         } else {
@@ -1184,6 +1191,7 @@ GitHost <- R6::R6Class(
       ) |>
         private$get_repo_url_from_response(
           type = type,
+          verbose = verbose,
           progress = progress
         )
     },
@@ -1199,6 +1207,7 @@ GitHost <- R6::R6Class(
         purrr::discard(~ is.null(.)) |>
         private$get_repo_url_from_response(
           type = type,
+          verbose = verbose,
           progress = progress
         )
     },
@@ -1215,6 +1224,7 @@ GitHost <- R6::R6Class(
         private$get_repo_url_from_response(
           type = type,
           repos_fullnames = private$repos_fullnames,
+          verbose = verbose,
           progress = progress
         )
     },
@@ -1242,7 +1252,8 @@ GitHost <- R6::R6Class(
         rest_engine <- private$engines$rest
         repos_table <- rest_engine$get_repos_contributors(
           repos_table = repos_table,
-          progress    = progress
+          verbose = verbose,
+          progress = progress
         )
         return(repos_table)
       }
@@ -1268,6 +1279,7 @@ GitHost <- R6::R6Class(
           issues_table_org <- graphql_engine$get_issues_from_repos(
             org = org,
             repos_names = repos_names,
+            verbose = verbose,
             progress = progress
           ) |>
             graphql_engine$prepare_issues_table(
@@ -1289,7 +1301,8 @@ GitHost <- R6::R6Class(
       if ("repo" %in% private$searching_scope) {
         graphql_engine <- private$engines$graphql
         orgs <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         )
         issues_table <- purrr::map(orgs, function(org) {
           issues_table_org <- NULL
@@ -1361,7 +1374,8 @@ GitHost <- R6::R6Class(
       if ("repo" %in% private$searching_scope) {
         graphql_engine <- private$engines$graphql
         orgs <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         )
         files_table <- purrr::map(orgs, function(org) {
           if (verbose) {
@@ -1488,7 +1502,8 @@ GitHost <- R6::R6Class(
       if ("repo" %in% private$searching_scope) {
         graphql_engine <- private$engines$graphql
         orgs <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         )
         files_structure_list <- purrr::map(orgs, function(org) {
           if (verbose) {
@@ -1544,7 +1559,8 @@ GitHost <- R6::R6Class(
         )
       }
       files_table <- rest_engine$get_files(
-        files = file_path
+        file_paths = file_path,
+        verbose = verbose
       ) |>
         rest_engine$prepare_files_table() |>
         private$add_repo_api_url()
@@ -1572,8 +1588,9 @@ GitHost <- R6::R6Class(
           if (length(repos_names) > 0) {
             release_logs_table_org <- graphql_engine$get_release_logs_from_org(
               repos_names = repos_names,
-              org = org
-            ) %>%
+              org = org,
+              verbose = verbose
+            ) |>
               graphql_engine$prepare_releases_table(
                 org = org,
                 since = since,
@@ -1597,7 +1614,8 @@ GitHost <- R6::R6Class(
       if ("repo" %in% private$searching_scope) {
         graphql_engine <- private$engines$graphql
         orgs <- graphql_engine$set_owner_type(
-          owners = names(private$orgs_repos)
+          owners = names(private$orgs_repos),
+          verbose = verbose
         )
         release_logs_table <- purrr::map(orgs, function(org) {
           org <- utils::URLdecode(org)
@@ -1612,8 +1630,9 @@ GitHost <- R6::R6Class(
           }
           release_logs_table_org <- graphql_engine$get_release_logs_from_org(
             repos_names = private$orgs_repos[[org]],
-            org = org
-          ) %>%
+            org = org,
+            verbose = verbose
+          ) |>
             graphql_engine$prepare_releases_table(
               org = org,
               since = since,
@@ -1628,6 +1647,13 @@ GitHost <- R6::R6Class(
           purrr::list_rbind()
         return(release_logs_table)
       }
+    },
+
+    filter_repos_table_by_language = function(repos_table, language_filter) {
+      if (!is.null(repos_table)) {
+        repos_table |>
+          dplyr::filter(grepl(paste0("\\b", language_filter, "\\b"), languages))
+      }
     }
   )
 )
