@@ -36,7 +36,7 @@ if (integration_tests_skipped) {
   gh_org <- "r-world-devs"
   gh_repo <- "GitStats"
   gh_user <- "maciekbanas"
-  gh_code <- "dplyr"
+  gh_code <- "GitStats"
   gh_file <- "DESCRIPTION"
 }
 
@@ -153,25 +153,26 @@ test_that("`search_response()` performs search with limit over 1000", {
     "self$response",
     test_fixtures$github_search_response_large
   )
-  gh_search_repos_response <- test_rest_github_priv$search_response(
+  gh_search_repos_response_large <- test_rest_github_priv$search_response(
     search_endpoint = test_mocker$use("search_endpoint"),
     total_n = total_n
   )
-  expect_gh_search_response(gh_search_repos_response)
-  test_mocker$cache(gh_search_repos_response)
+  expect_gh_search_response(gh_search_repos_response_large)
 })
 
 test_that("`search_for_code()` returns repos output for code search in files", {
-  mockery::stub(
-    test_rest_github$search_for_code,
-    "self$response",
-    list("total_count" = 3L)
-  )
-  mockery::stub(
-    test_rest_github$search_for_code,
-    "private$search_response",
-    test_fixtures$github_search_response
-  )
+  if (integration_tests_skipped) {
+    mockery::stub(
+      test_rest_github$search_for_code,
+      "self$response",
+      list("total_count" = 3L)
+    )
+    mockery::stub(
+      test_rest_github$search_for_code,
+      "private$search_response",
+      test_fixtures$github_search_response$items
+    )
+  }
   gh_search_for_code <- test_rest_github$search_for_code(
     code = gh_code,
     filename = gh_file,
@@ -179,32 +180,59 @@ test_that("`search_for_code()` returns repos output for code search in files", {
     org = gh_org,
     verbose = FALSE
   )
-  expect_gh_search_response(gh_search_for_code$items)
+  expect_gh_search_response(gh_search_for_code)
   test_mocker$cache(gh_search_for_code)
 })
 
 test_that("`search_repos_for_code()` returns repos output for code search in files", {
-  mockery::stub(
-    test_rest_github$search_repos_for_code,
-    "self$response",
-    list("total_count" = 3L)
-  )
-  mockery::stub(
-    test_rest_github$search_repos_for_code,
-    "private$search_response",
-    test_fixtures$github_search_response
-  )
+  if (integration_tests_skipped) {
+    mockery::stub(
+      test_rest_github$search_repos_for_code,
+      "self$response",
+      list("total_count" = 3L)
+    )
+    mockery::stub(
+      test_rest_github$search_repos_for_code,
+      "private$search_response",
+      test_fixtures$github_search_response$items
+    )
+  }
   gh_search_repos_for_code <- test_rest_github$search_repos_for_code(
     code = gh_code,
     filename = gh_file,
     in_path = FALSE,
-    repos = gh_org,
+    language = "R",
+    repos = paste0(gh_org, "/", gh_repo),
     verbose = FALSE
   )
-  expect_gh_search_response(gh_search_repos_for_code$items)
+  expect_gh_search_response(gh_search_repos_for_code)
   test_mocker$cache(gh_search_repos_for_code)
 })
 
+test_that("`search_for_code()` works with language filter", {
+  if (integration_tests_skipped) {
+    mockery::stub(
+      test_rest_github$search_for_code,
+      "self$response",
+      list("total_count" = 3L)
+    )
+    mockery::stub(
+      test_rest_github$search_for_code,
+      "private$search_response",
+      test_fixtures$github_search_response$items
+    )
+  }
+  gh_search_for_code_language <- test_rest_github$search_for_code(
+    code = gh_code,
+    filename = gh_file,
+    in_path = FALSE,
+    language = "R",
+    verbose = FALSE
+  )
+  expect_gh_search_response(gh_search_for_code_language)
+  test_mocker$cache(gh_search_for_code_language)
+})
+
 test_that("`prepare_repos_table()` prepares repos table", {
   gh_repos_by_code_table <- test_graphql_github$prepare_repos_table(
       repos_list = test_mocker$use("gh_repos_from_org"),
@@ -218,7 +246,7 @@ test_that("`prepare_repos_table()` prepares repos table", {
 
 test_that("get_repos_ids", {
   repos_ids <- github_testhost_priv$get_repos_ids(
-    search_response = test_mocker$use("gh_search_repos_for_code")[["items"]]
+    search_response = test_mocker$use("gh_search_repos_for_code")
   )
   expect_type(
     repos_ids,
@@ -232,12 +260,13 @@ test_that("get_repos_ids", {
 test_that("parse_search_response parses search response into repositories output", {
   mockery::stub(
     github_testhost_priv$parse_search_response,
-    "graphql_engine$get_repos",
+    "api_engine$get_repos",
     test_mocker$use("gh_repos_by_ids")
   )
   gh_repos_raw_output <- github_testhost_priv$parse_search_response(
-    search_response = test_mocker$use("gh_search_repos_for_code")[["items"]],
-    output = "raw"
+    search_response = test_mocker$use("gh_search_repos_for_code"),
+    output = "raw",
+    verbose = FALSE
   )
   expect_gh_repos_gql_response(gh_repos_raw_output[[1]])
   test_mocker$cache(gh_repos_raw_output)
@@ -246,23 +275,40 @@ test_that("parse_search_response parses search response into repositories output
 test_that("parse_search_response parses search response into repositories output", {
   mockery::stub(
     github_testhost_priv$parse_search_response,
-    "graphql_engine$get_repos_from_org",
-    test_mocker$use("gh_repos_from_org")
+    "api_engine$get_repos",
+    test_mocker$use("gh_repos_by_ids")
   )
   gh_repos_by_code_table <- github_testhost_priv$parse_search_response(
-    search_response = test_mocker$use("gh_search_repos_for_code")[["items"]],
+    search_response = test_mocker$use("gh_search_repos_for_code"),
     org = gh_org,
-    output = "table"
+    output = "table",
+    verbose = FALSE
   )
   expect_repos_table(gh_repos_by_code_table)
   test_mocker$cache(gh_repos_by_code_table)
 })
 
+test_that("parse_search_response prints message", {
+  mockery::stub(
+    github_testhost_priv$parse_search_response,
+    "api_engine$get_repos_from_org",
+    test_mocker$use("gh_repos_by_ids")
+  )
+  expect_snapshot(
+    gh_repos_raw_output <- github_testhost_priv$parse_search_response(
+      search_response = test_mocker$use("gh_search_repos_for_code"),
+      org = gh_org,
+      output = "raw",
+      verbose = TRUE
+    )
+  )
+})
+
 test_that("`get_repos_with_code_from_orgs()` works", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
     "rest_engine$search_for_code",
-    test_mocker$use("gh_search_repos_for_code")[["items"]]
+    test_mocker$use("gh_search_repos_for_code")
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
@@ -282,7 +328,7 @@ test_that("`get_repos_with_code_from_orgs()` pulls raw response", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
     "rest_engine$search_for_code",
-    test_mocker$use("gh_search_repos_for_code")[["items"]]
+    test_mocker$use("gh_search_repos_for_code")
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
@@ -294,6 +340,7 @@ test_that("`get_repos_with_code_from_orgs()` pulls raw response", {
     repos_with_code_from_orgs_raw <- github_testhost_priv$get_repos_with_code_from_orgs(
       code = "shiny",
       in_files = c("DESCRIPTION", "NAMESPACE"),
+      language = "R",
       output = "raw",
       verbose = TRUE
     )
@@ -306,7 +353,7 @@ test_that("`get_repos_with_code_from_host()` pulls and parses output into table"
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
     "rest_engine$search_for_code",
-    test_mocker$use("gh_search_repos_for_code")[["items"]]
+    test_mocker$use("gh_search_repos_for_code")
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
@@ -333,7 +380,7 @@ test_that("`get_repos_with_code_from_repos()` works", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_repos,
     "rest_engine$search_repos_for_code",
-    test_mocker$use("gh_search_repos_for_code")[["items"]]
+    test_mocker$use("gh_search_repos_for_code")
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_repos,
@@ -351,27 +398,11 @@ test_that("`get_repos_with_code_from_repos()` works", {
   expect_repos_table(repos_with_code_from_repos_full)
 })
 
-test_that("`get_repos_with_code_from_host()` pulls raw response", {
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code_from_host,
-    "rest_engine$search_repos_for_code",
-    test_mocker$use("gh_search_repos_for_code")[["items"]]
-  )
-  expect_snapshot(
-    repos_with_code_from_host_raw <- github_testhost_priv$get_repos_with_code_from_host(
-      code = "shiny",
-      in_files = c("DESCRIPTION", "NAMESPACE"),
-      output = "raw",
-      verbose = TRUE
-    )
-  )
-})
-
 test_that("`get_repos_with_code_from_host()` pulls raw response", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
     "rest_engine$search_for_code",
-    test_mocker$use("gh_search_repos_for_code")[["items"]]
+    test_mocker$use("gh_search_repos_for_code")
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
@@ -641,6 +672,7 @@ test_that("`get_repos()` works as expected", {
   )
   gh_repos_table_full <- github_testhost$get_repos(
     add_contributors = TRUE,
+    language = "R",
     verbose = FALSE
   )
   expect_repos_table(
@@ -649,3 +681,29 @@ test_that("`get_repos()` works as expected", {
   )
   test_mocker$cache(gh_repos_table_full)
 })
+
+test_that("filtering by language works", {
+  repos_table <- test_mocker$use("gh_repos_table_full")
+  repos_table$languages[1] <- "Python"
+  filtered_repos <- github_testhost_priv$filter_repos_table_by_language(
+    repos_table = repos_table,
+    language_filter = "R"
+  )
+  expect_gt(
+    nrow(filtered_repos),
+    0
+  )
+  expect_gt(
+    nrow(repos_table),
+    nrow(filtered_repos)
+  )
+})
+
+test_that("filtering by language does not fail when NULL is passed as input", {
+  expect_no_error({
+    filtered_repos <- github_testhost_priv$filter_repos_table_by_language(
+      repos_table = NULL,
+      language_filter = "R"
+    )
+  })
+})
