@@ -107,7 +107,7 @@ test_that("`get_release_logs()` is set to scan whole git host", {
   github_testhost_all <- create_github_testhost_all(orgs = "test_org")
   mockery::stub(
     github_testhost_all$get_release_logs,
-    "graphql_engine$get_orgs",
+    "private$get_orgs_from_host",
     "test_org"
   )
   mockery::stub(
@@ -120,8 +120,8 @@ test_that("`get_release_logs()` is set to scan whole git host", {
     "private$get_release_logs_from_orgs",
     test_mocker$use("releases_from_orgs")
   )
-  expect_snapshot(
-    gh_releases_table <- github_testhost_all$get_release_logs(
+  expect_releases_table(
+    github_testhost_all$get_release_logs(
       since    = "2023-01-01",
       until    = "2023-02-28",
       verbose  = TRUE,
